=== modified file 'bzrlib/commit_signature_commands.py'
--- bzrlib/commit_signature_commands.py	2012-03-11 16:51:49 +0000
+++ bzrlib/commit_signature_commands.py	2013-11-10 15:29:06 +0000
@@ -111,7 +111,7 @@
                         ' acceptable for verification.',
                    short_name='k',
                    type=str,),
-            'revision', 
+            'revision',
             'verbose',
           ]
     takes_args = ['location?']
@@ -160,8 +160,8 @@
                     # Ignore ghosts
                     continue
                 revisions.append(rev_id)
-        count, result, all_verifiable =\
-                                gpg.bulk_verify_signatures(repo, revisions, gpg_strategy)
+        count, result, all_verifiable = gpg.bulk_verify_signatures(
+            repo, revisions, gpg_strategy)
         if all_verifiable:
                write(gettext("All commits signed with verifiable keys"))
                if verbose:

=== modified file 'bzrlib/gpg.py'
--- bzrlib/gpg.py	2012-06-29 08:12:32 +0000
+++ bzrlib/gpg.py	2013-11-10 15:29:06 +0000
@@ -336,23 +336,14 @@
                                 command line
         :return: nothing
         """
-        key_patterns = None
+        patterns = None
         acceptable_keys_config = self._config_stack.get('acceptable_keys')
-        try:
-            if isinstance(acceptable_keys_config, unicode):
-                acceptable_keys_config = str(acceptable_keys_config)
-        except UnicodeEncodeError:
-            # gpg Context.keylist(pattern) does not like unicode
-            raise errors.BzrCommandError(
-                gettext('Only ASCII permitted in option names'))
-
         if acceptable_keys_config is not None:
-            key_patterns = acceptable_keys_config
+            patterns = acceptable_keys_config
         if command_line_input is not None: # command line overrides config
-            key_patterns = command_line_input
-        if key_patterns is not None:
-            patterns = key_patterns.split(",")
+            patterns = command_line_input.split(',')
 
+        if patterns:
             self.acceptable_keys = []
             for pattern in patterns:
                 result = self.context.keylist(pattern)

=== modified file 'bzrlib/tests/test_gpg.py'
--- bzrlib/tests/test_gpg.py	2012-06-26 23:04:30 +0000
+++ bzrlib/tests/test_gpg.py	2013-11-10 15:29:06 +0000
@@ -499,6 +499,15 @@
         self.assertEqual(my_gpg.acceptable_keys,
                          [u'B5DEED5FCB15DAE6ECEF919587681B1EE3080E45'])
 
+    def test_set_acceptable_keys_from_config(self):
+        self.requireFeature(features.gpgme)
+        self.import_keys()
+        my_gpg = gpg.GPGStrategy(FakeConfig(
+                'acceptable_keys=bazaar@example.com'))
+        my_gpg.set_acceptable_keys(None)
+        self.assertEqual(my_gpg.acceptable_keys,
+                         [u'B5DEED5FCB15DAE6ECEF919587681B1EE3080E45'])
+
     def test_set_acceptable_keys_unknown(self):
         self.requireFeature(features.gpgme)
         my_gpg = gpg.GPGStrategy(FakeConfig())

=== modified file 'doc/en/release-notes/bzr-2.7.txt'
--- doc/en/release-notes/bzr-2.7.txt	2013-10-07 16:35:59 +0000
+++ doc/en/release-notes/bzr-2.7.txt	2013-11-10 15:29:06 +0000
@@ -32,6 +32,9 @@
 .. Fixes for situations where bzr would previously crash or give incorrect
    or undesirable results.
 
+* 'acceptable_keys' from 'bazzar.conf' is not properly handled.
+  (Vincent Ladeuil, #1249732)
+
 * Option names are now checked to be valid [dotted] python identifiers. Also
   ignore invalid references (i.e. using invalid option names) while
   expanding option values. (Vincent Ladeuil, #1235099)

